@@ -1,6 +1,5 @@
 import os
 import json
-import click
 from gitignore_parser import parse_gitignore
 
 from ..common.messages_service import MessagesService
@@ -8,6 +7,8 @@ from chips.common.basic_excludes import BASIC_EXCLUDES
 from ast2json import ast2json
 from prettytable import PrettyTable as pt
 
+import sys
+
 messages = MessagesService()
 
 
@@ -97,7 +98,7 @@ class ChipService:
             if triggers_list:
                 messages.warning("Current trigger progress will be lost!")
 
-            if click.confirm('Do you want to continue?', default=True):
+            if self.user_yes_no_query('Do you want to continue?'):
                 pass
             else:
                 return "No files were chipped", [], []
@@ -157,6 +158,19 @@ class ChipService:
         else:
             return "No files were chipped", chipped_failure_files_list, chipped_skipped_files_list
 
+    @staticmethod
+    def user_yes_no_query(question):
+        sys.stdout.write('%s [Y/n]\n' % question)
+        no_answer = True
+        while no_answer:
+            _input = input()
+            if _input == "" or _input == "y":
+                return True
+            elif _input == "n":
+                return False
+            else:
+                sys.stdout.write('Please respond with [Y/n]\n')
+
     @classmethod
     def remove_chips(cls,
                      path: str = None,
@@ -213,7 +227,7 @@ class ChipService:
         if not _silent:
             messages.info(f"Chips will be removed for files: {', '.join(work_filenames)}")
 
-            if click.confirm('Do you want to continue?', default=True):
+            if cls.user_yes_no_query('Do you want to continue?'):
                 pass
             else:
                 return "Chips were removed from 0 files", [], []
@@ -278,10 +292,13 @@ class ChipService:
         def _iterate_tree(_tree_json: dict, _idx_counter: int, first_iter: bool, tab_iter: int):
             for thread in _tree_json:
                 _idx_counter += 1
+
+                # TODO: Check
+                chip_id = "dummy_value123"
                 if "id" in thread:
                     chip_id = thread["id"]
 
-                if thread["type"] == "def":
+                if thread["type"] == "def " and chip_id:
                     mark = "✅" if chip_id in trig_json else "❌"
                 else:
                     mark = ""
@@ -448,30 +465,32 @@ class ChipService:
         def _parse_code_for_defs(rec_item: dict, defs_am: int, c_tree: list):
 
             for body_item in rec_item["body"]:
-                c_tree_dict = {}
-                # FUNCTIONS
-                if body_item["_type"] == "FunctionDef":
-                    if "name" in body_item:
-                        defs_am += 1
-                        c_tree_dict["name"] = body_item["name"]
-                        c_tree_dict["type"] = "def"
-                        c_tree_dict["id"] = cls._generate_func_token()
-                        # c_tree_dict["triggered"] = False
-                        if "body" in body_item:
-                            c_tree_dict = {**c_tree_dict, "body": []}
-                            _parse_code_for_defs(body_item, defs_am, c_tree_dict["body"])
-                # CLASSES
-                if body_item["_type"] == "ClassDef":
-                    if "name" in body_item:
-                        c_tree_dict["name"] = body_item["name"]
-                        c_tree_dict["type"] = "class"
-                        # c_tree_dict["triggered"] = False
-                        if "body" in body_item:
-                            c_tree_dict = {**c_tree_dict, "body": []}
-                            _parse_code_for_defs(body_item, defs_am, c_tree_dict["body"])
+                if body_item["_type"] == "FunctionDef" or body_item["_type"] == "ClassDef":
+                    c_tree_dict = {}
+                    # FUNCTIONS
+                    if body_item["_type"] == "FunctionDef":
+                        if "name" in body_item:
+                            defs_am += 1
+                            c_tree_dict["name"] = body_item["name"]
+                            c_tree_dict["type"] = "def"
+                            c_tree_dict["id"] = cls._generate_func_token()
+                            # c_tree_dict["triggered"] = False
+                            if "body" in body_item:
+                                c_tree_dict = {**c_tree_dict, "body": []}
+                                _parse_code_for_defs(body_item, defs_am, c_tree_dict["body"])
+                    # CLASSES
+                    if body_item["_type"] == "ClassDef":
+                        if "name" in body_item:
+                            defs_am += 1
+                            c_tree_dict["name"] = body_item["name"]
+                            c_tree_dict["type"] = "class"
+                            # c_tree_dict["triggered"] = False
+                            if "body" in body_item:
+                                c_tree_dict = {**c_tree_dict, "body": []}
+                                _parse_code_for_defs(body_item, defs_am, c_tree_dict["body"])
 
-                if c_tree_dict:
-                    c_tree.append(c_tree_dict)
+                    if c_tree_dict:
+                        c_tree.append(c_tree_dict)
 
             return c_tree, defs_am
 
@@ -509,9 +528,9 @@ class ChipService:
         if code_tree:
             for line in lines_iter:
                 updated_file += line + "\n"
-                if "def" in line:
+                if "def " in line:
                     # GET FUNC NAME
-                    func_name = line.split("def", 1)[1].partition("(")[0].replace(':', '').strip()
+                    func_name = line.split("def ", 1)[1].partition("(")[0].replace(':', '').strip()
 
                     # ITERATE UNTIL THE ACTUAL BEGINNING OF THE FUNCTION
                     k = idx
@@ -569,16 +588,15 @@ class ChipService:
 
     @classmethod
     def _get_chip_id_by_func_name(cls, func_name: str, tree: list):
-        chip_id = None
         for thread in tree:
             if thread["name"] == func_name:
                 chip_id = thread["id"]
-                break
+                return chip_id
 
             if thread["body"]:
                 chip_id = cls._get_chip_id_by_func_name(func_name, thread["body"])
-
-        return chip_id
+                if chip_id:
+                    return chip_id
 
     @staticmethod
     def _remove_chip_from_file(file_path: str):
